@@ -1,7 +1,7 @@
 package Tk::HList; 
 
 use vars qw($VERSION @ISA);
-$VERSION = '3.011'; # $Id: //depot/Tk8/HList/HList.pm#11$
+$VERSION = '3.012'; # $Id: //depot/Tk8/HList/HList.pm#12$
 
 use Tk qw(Ev);
 
@@ -602,7 +602,7 @@ sub AutoScan
   {
    return;
   }
- $w->RepeatId($w->after(50,"AutoScan",$w));
+ $w->RepeatId($w->SUPER::after(50,"AutoScan",$w));
  $w->Button1Motion;
 }
 
