@@ -6,14 +6,14 @@ package Tk::Checkbutton;
 # This program is free software; you can redistribute it and/or
 
 
-use vars qw($VERSION);
-$VERSION = '3.004'; # $Id: //depot/Tk8/Tk/Checkbutton.pm#4$
+use vars qw($VERSION @ISA);
+$VERSION = '3.005'; # $Id: //depot/Tk8/Tk/Checkbutton.pm#5$
 
 # modify it under the same terms as Perl itself, subject 
 # to additional disclaimer in license.terms due to partial
 # derivation from Tk4.0 sources.
 
-use AutoLoader;
+require Tk::Widget;
 require Tk::Button;
 
 @ISA = qw(Tk::Button);
@@ -22,8 +22,6 @@ Construct Tk::Widget 'Checkbutton';
 
 sub Tk_cmd { \&Tk::checkbutton }
 
-1;
-__END__
 
 sub ClassInit
 {
